/***************************************************************************
 *   Copyright (C) 2003 by Sylvain Joyeux                                  *
 *   sylvain.joyeux@m4x.org                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
#include "packagemanager.h"

PackageManager::PackageManager(QObject *parent, const char *name)
 : QObject(parent, name) {}


PackageManager::~PackageManager() {}

bool PackageManager::list( const QString & /*package*/ ) { return false; }
bool PackageManager::search( const QString & /*file*/ ) { return false; }

int PackageManager::capabilities( int /*query*/ ) const { return 0; }

QString PackageManager::getOnlineForm() 
{ return QString::null; }
QString PackageManager::getOnlineURL
    ( const QString& /* query */
    , const QMap<QString, QString>& /*options*/ )  
{ return QString::null; }

#include "packagemanager.moc"

